==> mingw-w64-duckdb-1.0.0-1.src.tar.zst: duckdb-1.0.0/tools/sqlite3_api_wrapper/include/duckdb_shell_wrapper.h <==
#define sqlite3AppendChar              duckdb_shell_sqlite3AppendChar
#define sqlite3StrAccumAppend          duckdb_shell_sqlite3StrAccumAppend
#define sqlite3StrAccumAppendAll       duckdb_shell_sqlite3StrAccumAppendAll
#define sqlite3StrAccumFinish          duckdb_shell_sqlite3StrAccumFinish
#define sqlite3StrAccumInit            duckdb_shell_sqlite3StrAccumInit
#define sqlite3StrAccumReset           duckdb_shell_sqlite3StrAccumReset
#define sqlite3Utf8Read                duckdb_shell_sqlite3Utf8Read
#define sqlite3VXPrintf                duckdb_shell_sqlite3VXPrintf
#define sqlite3_aggregate_context      duckdb_shell_sqlite3_aggregate_context
#define sqlite3_backup_finish          duckdb_shell_sqlite3_backup_finish
#define sqlite3_backup_init            duckdb_shell_sqlite3_backup_init
#define sqlite3_backup_step            duckdb_shell_sqlite3_backup_step
#define sqlite3_bind_blob              duckdb_shell_sqlite3_bind_blob
#define sqlite3_bind_double            duckdb_shell_sqlite3_bind_double
#define sqlite3_bind_int               duckdb_shell_sqlite3_bind_int
#define sqlite3_bind_int64             duckdb_shell_sqlite3_bind_int64
#define sqlite3_bind_null              duckdb_shell_sqlite3_bind_null
#define sqlite3_bind_parameter_count   duckdb_shell_sqlite3_bind_parameter_count
#define sqlite3_bind_parameter_index   duckdb_shell_sqlite3_bind_parameter_index
#define sqlite3_bind_parameter_name    duckdb_shell_sqlite3_bind_parameter_name
#define sqlite3_bind_pointer           duckdb_shell_sqlite3_bind_pointer
#define sqlite3_bind_text              duckdb_shell_sqlite3_bind_text
#define sqlite3_bind_value             duckdb_shell_sqlite3_bind_value
#define sqlite3_bind_zeroblob          duckdb_shell_sqlite3_bind_zeroblob
#define sqlite3_blob_open              duckdb_shell_sqlite3_blob_open
#define sqlite3_blob_write             duckdb_shell_sqlite3_blob_write
#define sqlite3_busy_handler           duckdb_shell_sqlite3_busy_handler
#define sqlite3_busy_timeout           duckdb_shell_sqlite3_busy_timeout
#define sqlite3_changes                duckdb_shell_sqlite3_changes
#define sqlite3_clear_bindings         duckdb_shell_sqlite3_clear_bindings
#define sqlite3_close                  duckdb_shell_sqlite3_close
#define sqlite3_collation_needed       duckdb_shell_sqlite3_collation_needed
#define sqlite3_column_blob            duckdb_shell_sqlite3_column_blob
#define sqlite3_column_bytes           duckdb_shell_sqlite3_column_bytes
#define sqlite3_column_count           duckdb_shell_sqlite3_column_count
#define sqlite3_column_decltype        duckdb_shell_sqlite3_column_decltype
#define sqlite3_column_double          duckdb_shell_sqlite3_column_double
#define sqlite3_column_int             duckdb_shell_sqlite3_column_int
#define sqlite3_column_int64           duckdb_shell_sqlite3_column_int64
#define sqlite3_column_name            duckdb_shell_sqlite3_column_name
#define sqlite3_column_table_name      duckdb_shell_sqlite3_column_table_name
#define sqlite3_column_text            duckdb_shell_sqlite3_column_text
#define sqlite3_column_type            duckdb_shell_sqlite3_column_type
#define sqlite3_column_value           duckdb_shell_sqlite3_column_value
#define sqlite3_commit_hook            duckdb_shell_sqlite3_commit_hook
#define sqlite3_complete               duckdb_shell_sqlite3_complete
#define sqlite3_config                 duckdb_shell_sqlite3_config
#define sqlite3_context_db_handle      duckdb_shell_sqlite3_context_db_handle
#define sqlite3_create_collation       duckdb_shell_sqlite3_create_collation
#define sqlite3_create_collation_v2    duckdb_shell_sqlite3_create_collation_v2
#define sqlite3_create_function        duckdb_shell_sqlite3_create_function
#define sqlite3_create_function_v2     duckdb_shell_sqlite3_create_function_v2
#define sqlite3_create_module          duckdb_shell_sqlite3_create_module
#define sqlite3_create_module_v2       duckdb_shell_sqlite3_create_module_v2
#define sqlite3_create_window_function duckdb_shell_sqlite3_create_window_function
#define sqlite3_db_config              duckdb_shell_sqlite3_db_config
#define sqlite3_db_filename            duckdb_shell_sqlite3_db_filename
#define sqlite3_db_handle              duckdb_shell_sqlite3_db_handle
#define sqlite3_db_status              duckdb_shell_sqlite3_db_status
#define sqlite3_declare_vtab           duckdb_shell_sqlite3_declare_vtab
#define sqlite3_enable_load_extension  duckdb_shell_sqlite3_enable_load_extension
#define sqlite3_errcode                duckdb_shell_sqlite3_errcode
#define sqlite3_errmsg                 duckdb_shell_sqlite3_errmsg
#define sqlite3_exec                   duckdb_shell_sqlite3_exec
#define sqlite3_expanded_sql           duckdb_shell_sqlite3_expanded_sql
#define sqlite3_extended_errcode       duckdb_shell_sqlite3_extended_errcode
#define sqlite3_extended_result_codes  duckdb_shell_sqlite3_extended_result_codes
#define sqlite3_file_control           duckdb_shell_sqlite3_file_control
#define sqlite3_finalize               duckdb_shell_sqlite3_finalize
#define sqlite3_free                   duckdb_shell_sqlite3_free
#define sqlite3_free_table             duckdb_shell_sqlite3_free_table
#define sqlite3_get_autocommit         duckdb_shell_sqlite3_get_autocommit
#define sqlite3_get_auxdata            duckdb_shell_sqlite3_get_auxdata
#define sqlite3_get_table              duckdb_shell_sqlite3_get_table
#define sqlite3_initialize             duckdb_shell_sqlite3_initialize
#define sqlite3_interrupt              duckdb_shell_sqlite3_interrupt
#define sqlite3_keyword_check          duckdb_shell_sqlite3_keyword_check
#define sqlite3_keyword_count          duckdb_shell_sqlite3_keyword_count
#define sqlite3_keyword_name           duckdb_shell_sqlite3_keyword_name
#define sqlite3_last_insert_rowid      duckdb_shell_sqlite3_last_insert_rowid
#define sqlite3_libversion             duckdb_shell_sqlite3_libversion
#define sqlite3_libversion_number      duckdb_shell_sqlite3_libversion_number
#define sqlite3_limit                  duckdb_shell_sqlite3_limit
#define sqlite3_load_extension         duckdb_shell_sqlite3_load_extension
#define sqlite3_log                    duckdb_shell_sqlite3_log
#define sqlite3_malloc                 duckdb_shell_sqlite3_malloc
#define sqlite3_malloc64               duckdb_shell_sqlite3_malloc64
#define sqlite3_mprintf                duckdb_shell_sqlite3_mprintf
#define sqlite3_mutex_alloc            duckdb_shell_sqlite3_mutex_alloc
#define sqlite3_mutex_free             duckdb_shell_sqlite3_mutex_free
#define sqlite3_next_stmt              duckdb_shell_sqlite3_next_stmt
#define sqlite3_open                   duckdb_shell_sqlite3_open
#define sqlite3_open_v2                duckdb_shell_sqlite3_open_v2
#define sqlite3_prepare                duckdb_shell_sqlite3_prepare
#define sqlite3_prepare_v2             duckdb_shell_sqlite3_prepare_v2
#define sqlite3_print_duckbox          duckdb_shell_sqlite3_print_duckbox
#define sqlite3_profile                duckdb_shell_sqlite3_profile
#define sqlite3_progress_handler       duckdb_shell_sqlite3_progress_handler
#define sqlite3_randomness             duckdb_shell_sqlite3_randomness
#define sqlite3_realloc                duckdb_shell_sqlite3_realloc
#define sqlite3_realloc64              duckdb_shell_sqlite3_realloc64
#define sqlite3_reset                  duckdb_shell_sqlite3_reset
#define sqlite3_result_blob            duckdb_shell_sqlite3_result_blob
#define sqlite3_result_blob64          duckdb_shell_sqlite3_result_blob64
#define sqlite3_result_double          duckdb_shell_sqlite3_result_double
#define sqlite3_result_error           duckdb_shell_sqlite3_result_error
#define sqlite3_result_error16         duckdb_shell_sqlite3_result_error16
#define sqlite3_result_error_code      duckdb_shell_sqlite3_result_error_code
#define sqlite3_result_error_nomem     duckdb_shell_sqlite3_result_error_nomem
#define sqlite3_result_error_toobig    duckdb_shell_sqlite3_result_error_toobig
#define sqlite3_result_int             duckdb_shell_sqlite3_result_int
#define sqlite3_result_int64           duckdb_shell_sqlite3_result_int64
#define sqlite3_result_null            duckdb_shell_sqlite3_result_null
#define sqlite3_result_pointer         duckdb_shell_sqlite3_result_pointer
#define sqlite3_result_text            duckdb_shell_sqlite3_result_text
#define sqlite3_result_text16          duckdb_shell_sqlite3_result_text16
#define sqlite3_result_text16be        duckdb_shell_sqlite3_result_text16be
#define sqlite3_result_text16le        duckdb_shell_sqlite3_result_text16le
#define sqlite3_result_text64          duckdb_shell_sqlite3_result_text64
#define sqlite3_result_value           duckdb_shell_sqlite3_result_value
#define sqlite3_result_zeroblob        duckdb_shell_sqlite3_result_zeroblob
#define sqlite3_result_zeroblob64      duckdb_shell_sqlite3_result_zeroblob64
#define sqlite3_rollback_hook          duckdb_shell_sqlite3_rollback_hook
#define sqlite3_set_authorizer         duckdb_shell_sqlite3_set_authorizer
#define sqlite3_set_auxdata            duckdb_shell_sqlite3_set_auxdata
#define sqlite3_shutdown               duckdb_shell_sqlite3_shutdown
#define sqlite3_sleep                  duckdb_shell_sqlite3_sleep
#define sqlite3_snprintf               duckdb_shell_sqlite3_snprintf
#define sqlite3_sourceid               duckdb_shell_sqlite3_sourceid
#define sqlite3_sql                    duckdb_shell_sqlite3_sql
#define sqlite3_status64               duckdb_shell_sqlite3_status64
#define sqlite3_step                   duckdb_shell_sqlite3_step
#define sqlite3_stmt_busy              duckdb_shell_sqlite3_stmt_busy
#define sqlite3_stmt_isexplain         duckdb_shell_sqlite3_stmt_isexplain
#define sqlite3_stmt_readonly          duckdb_shell_sqlite3_stmt_readonly
#define sqlite3_stmt_status            duckdb_shell_sqlite3_stmt_status
#define sqlite3_strglob                duckdb_shell_sqlite3_strglob
#define sqlite3_stricmp                duckdb_shell_sqlite3_stricmp
#define sqlite3_strlike                duckdb_shell_sqlite3_strlike
#define sqlite3_strnicmp               duckdb_shell_sqlite3_strnicmp
#define sqlite3_table_column_metadata  duckdb_shell_sqlite3_table_column_metadata
#define sqlite3_test_control           duckdb_shell_sqlite3_test_control
#define sqlite3_threadsafe             duckdb_shell_sqlite3_threadsafe
#define sqlite3_total_changes          duckdb_shell_sqlite3_total_changes
#define sqlite3_trace                  duckdb_shell_sqlite3_trace
#define sqlite3_trace_v2               duckdb_shell_sqlite3_trace_v2
#define sqlite3_unlock_notify          duckdb_shell_sqlite3_unlock_notify
#define sqlite3_update_hook            duckdb_shell_sqlite3_update_hook
#define sqlite3_user_data              duckdb_shell_sqlite3_user_data
#define sqlite3_value_blob             duckdb_shell_sqlite3_value_blob
#define sqlite3_value_bytes            duckdb_shell_sqlite3_value_bytes
#define sqlite3_value_bytes16          duckdb_shell_sqlite3_value_bytes16
#define sqlite3_value_double           duckdb_shell_sqlite3_value_double
#define sqlite3_value_dup              duckdb_shell_sqlite3_value_dup
#define sqlite3_value_free             duckdb_shell_sqlite3_value_free
#define sqlite3_value_int              duckdb_shell_sqlite3_value_int
#define sqlite3_value_int64            duckdb_shell_sqlite3_value_int64
#define sqlite3_value_nochange         duckdb_shell_sqlite3_value_nochange
#define sqlite3_value_numeric_type     duckdb_shell_sqlite3_value_numeric_type
#define sqlite3_value_pointer          duckdb_shell_sqlite3_value_pointer
#define sqlite3_value_text             duckdb_shell_sqlite3_value_text
#define sqlite3_value_text16           duckdb_shell_sqlite3_value_text16
#define sqlite3_value_text16be         duckdb_shell_sqlite3_value_text16be
#define sqlite3_value_text16le         duckdb_shell_sqlite3_value_text16le
#define sqlite3_value_type             duckdb_shell_sqlite3_value_type
#define sqlite3_vfs_find               duckdb_shell_sqlite3_vfs_find
#define sqlite3_vfs_register           duckdb_shell_sqlite3_vfs_register
#define sqlite3_vmprintf               duckdb_shell_sqlite3_vmprintf
#define sqlite3_vsnprintf              duckdb_shell_sqlite3_vsnprintf
#define sqlite3_vtab_collation         duckdb_shell_sqlite3_vtab_collation
#define sqlite3_vtab_config            duckdb_shell_sqlite3_vtab_config

==> mingw-w64-duckdb-1.2.0-1.src.tar.zst: duckdb-1.2.0/tools/sqlite3_api_wrapper/include/duckdb_shell_wrapper.h <==
#define sqlite3AppendChar              duckdb_shell_sqlite3AppendChar
#define sqlite3StrAccumAppend          duckdb_shell_sqlite3StrAccumAppend
#define sqlite3StrAccumAppendAll       duckdb_shell_sqlite3StrAccumAppendAll
#define sqlite3StrAccumFinish          duckdb_shell_sqlite3StrAccumFinish
#define sqlite3StrAccumInit            duckdb_shell_sqlite3StrAccumInit
#define sqlite3StrAccumReset           duckdb_shell_sqlite3StrAccumReset
#define sqlite3Utf8Read                duckdb_shell_sqlite3Utf8Read
#define sqlite3VXPrintf                duckdb_shell_sqlite3VXPrintf
#define sqlite3_aggregate_context      duckdb_shell_sqlite3_aggregate_context
#define sqlite3_backup_finish          duckdb_shell_sqlite3_backup_finish
#define sqlite3_backup_init            duckdb_shell_sqlite3_backup_init
#define sqlite3_backup_step            duckdb_shell_sqlite3_backup_step
#define sqlite3_bind_blob              duckdb_shell_sqlite3_bind_blob
#define sqlite3_bind_double            duckdb_shell_sqlite3_bind_double
#define sqlite3_bind_int               duckdb_shell_sqlite3_bind_int
#define sqlite3_bind_int64             duckdb_shell_sqlite3_bind_int64
#define sqlite3_bind_null              duckdb_shell_sqlite3_bind_null
#define sqlite3_bind_parameter_count   duckdb_shell_sqlite3_bind_parameter_count
#define sqlite3_bind_parameter_index   duckdb_shell_sqlite3_bind_parameter_index
#define sqlite3_bind_parameter_name    duckdb_shell_sqlite3_bind_parameter_name
#define sqlite3_bind_pointer           duckdb_shell_sqlite3_bind_pointer
#define sqlite3_bind_text              duckdb_shell_sqlite3_bind_text
#define sqlite3_bind_value             duckdb_shell_sqlite3_bind_value
#define sqlite3_bind_zeroblob          duckdb_shell_sqlite3_bind_zeroblob
#define sqlite3_blob_open              duckdb_shell_sqlite3_blob_open
#define sqlite3_blob_write             duckdb_shell_sqlite3_blob_write
#define sqlite3_busy_handler           duckdb_shell_sqlite3_busy_handler
#define sqlite3_busy_timeout           duckdb_shell_sqlite3_busy_timeout
#define sqlite3_changes                duckdb_shell_sqlite3_changes
#define sqlite3_changes64              duckdb_shell_sqlite3_changes64
#define sqlite3_clear_bindings         duckdb_shell_sqlite3_clear_bindings
#define sqlite3_close                  duckdb_shell_sqlite3_close
#define sqlite3_collation_needed       duckdb_shell_sqlite3_collation_needed
#define sqlite3_column_blob            duckdb_shell_sqlite3_column_blob
#define sqlite3_column_bytes           duckdb_shell_sqlite3_column_bytes
#define sqlite3_column_count           duckdb_shell_sqlite3_column_count
#define sqlite3_column_decltype        duckdb_shell_sqlite3_column_decltype
#define sqlite3_column_double          duckdb_shell_sqlite3_column_double
#define sqlite3_column_int             duckdb_shell_sqlite3_column_int
#define sqlite3_column_int64           duckdb_shell_sqlite3_column_int64
#define sqlite3_column_name            duckdb_shell_sqlite3_column_name
#define sqlite3_column_table_name      duckdb_shell_sqlite3_column_table_name
#define sqlite3_column_text            duckdb_shell_sqlite3_column_text
#define sqlite3_column_type            duckdb_shell_sqlite3_column_type
#define sqlite3_column_value           duckdb_shell_sqlite3_column_value
#define sqlite3_commit_hook            duckdb_shell_sqlite3_commit_hook
#define sqlite3_complete               duckdb_shell_sqlite3_complete
#define sqlite3_config                 duckdb_shell_sqlite3_config
#define sqlite3_context_db_handle      duckdb_shell_sqlite3_context_db_handle
#define sqlite3_create_collation       duckdb_shell_sqlite3_create_collation
#define sqlite3_create_collation_v2    duckdb_shell_sqlite3_create_collation_v2
#define sqlite3_create_function        duckdb_shell_sqlite3_create_function
#define sqlite3_create_function_v2     duckdb_shell_sqlite3_create_function_v2
#define sqlite3_create_module          duckdb_shell_sqlite3_create_module
#define sqlite3_create_module_v2       duckdb_shell_sqlite3_create_module_v2
#define sqlite3_create_window_function duckdb_shell_sqlite3_create_window_function
#define sqlite3_db_config              duckdb_shell_sqlite3_db_config
#define sqlite3_db_filename            duckdb_shell_sqlite3_db_filename
#define sqlite3_db_handle              duckdb_shell_sqlite3_db_handle
#define sqlite3_db_status              duckdb_shell_sqlite3_db_status
#define sqlite3_declare_vtab           duckdb_shell_sqlite3_declare_vtab
#define sqlite3_enable_load_extension  duckdb_shell_sqlite3_enable_load_extension
#define sqlite3_errcode                duckdb_shell_sqlite3_errcode
#define sqlite3_errmsg                 duckdb_shell_sqlite3_errmsg
#define sqlite3_exec                   duckdb_shell_sqlite3_exec
#define sqlite3_expanded_sql           duckdb_shell_sqlite3_expanded_sql
#define sqlite3_extended_errcode       duckdb_shell_sqlite3_extended_errcode
#define sqlite3_extended_result_codes  duckdb_shell_sqlite3_extended_result_codes
#define sqlite3_file_control           duckdb_shell_sqlite3_file_control
#define sqlite3_finalize               duckdb_shell_sqlite3_finalize
#define sqlite3_free                   duckdb_shell_sqlite3_free
#define sqlite3_free_table             duckdb_shell_sqlite3_free_table
#define sqlite3_get_autocommit         duckdb_shell_sqlite3_get_autocommit
#define sqlite3_get_auxdata            duckdb_shell_sqlite3_get_auxdata
#define sqlite3_get_table              duckdb_shell_sqlite3_get_table
#define sqlite3_initialize             duckdb_shell_sqlite3_initialize
#define sqlite3_interrupt              duckdb_shell_sqlite3_interrupt
#define sqlite3_keyword_check          duckdb_shell_sqlite3_keyword_check
#define sqlite3_keyword_count          duckdb_shell_sqlite3_keyword_count
#define sqlite3_keyword_name           duckdb_shell_sqlite3_keyword_name
#define sqlite3_last_insert_rowid      duckdb_shell_sqlite3_last_insert_rowid
#define sqlite3_libversion             duckdb_shell_sqlite3_libversion
#define sqlite3_libversion_number      duckdb_shell_sqlite3_libversion_number
#define sqlite3_limit                  duckdb_shell_sqlite3_limit
#define sqlite3_load_extension         duckdb_shell_sqlite3_load_extension
#define sqlite3_log                    duckdb_shell_sqlite3_log
#define sqlite3_malloc                 duckdb_shell_sqlite3_malloc
#define sqlite3_malloc64               duckdb_shell_sqlite3_malloc64
#define sqlite3_mprintf                duckdb_shell_sqlite3_mprintf
#define sqlite3_mutex_alloc            duckdb_shell_sqlite3_mutex_alloc
#define sqlite3_mutex_free             duckdb_shell_sqlite3_mutex_free
#define sqlite3_next_stmt              duckdb_shell_sqlite3_next_stmt
#define sqlite3_open                   duckdb_shell_sqlite3_open
#define sqlite3_open_v2                duckdb_shell_sqlite3_open_v2
#define sqlite3_prepare                duckdb_shell_sqlite3_prepare
#define sqlite3_prepare_v2             duckdb_shell_sqlite3_prepare_v2
#define sqlite3_print_duckbox          duckdb_shell_sqlite3_print_duckbox
#define sqlite3_profile                duckdb_shell_sqlite3_profile
#define sqlite3_progress_handler       duckdb_shell_sqlite3_progress_handler
#define sqlite3_randomness             duckdb_shell_sqlite3_randomness
#define sqlite3_realloc                duckdb_shell_sqlite3_realloc
#define sqlite3_realloc64              duckdb_shell_sqlite3_realloc64
#define sqlite3_reset                  duckdb_shell_sqlite3_reset
#define sqlite3_result_blob            duckdb_shell_sqlite3_result_blob
#define sqlite3_result_blob64          duckdb_shell_sqlite3_result_blob64
#define sqlite3_result_double          duckdb_shell_sqlite3_result_double
#define sqlite3_result_error           duckdb_shell_sqlite3_result_error
#define sqlite3_result_error16         duckdb_shell_sqlite3_result_error16
#define sqlite3_result_error_code      duckdb_shell_sqlite3_result_error_code
#define sqlite3_result_error_nomem     duckdb_shell_sqlite3_result_error_nomem
#define sqlite3_result_error_toobig    duckdb_shell_sqlite3_result_error_toobig
#define sqlite3_result_int             duckdb_shell_sqlite3_result_int
#define sqlite3_result_int64           duckdb_shell_sqlite3_result_int64
#define sqlite3_result_null            duckdb_shell_sqlite3_result_null
#define sqlite3_result_pointer         duckdb_shell_sqlite3_result_pointer
#define sqlite3_result_text            duckdb_shell_sqlite3_result_text
#define sqlite3_result_text16          duckdb_shell_sqlite3_result_text16
#define sqlite3_result_text16be        duckdb_shell_sqlite3_result_text16be
#define sqlite3_result_text16le        duckdb_shell_sqlite3_result_text16le
#define sqlite3_result_text64          duckdb_shell_sqlite3_result_text64
#define sqlite3_result_value           duckdb_shell_sqlite3_result_value
#define sqlite3_result_zeroblob        duckdb_shell_sqlite3_result_zeroblob
#define sqlite3_result_zeroblob64      duckdb_shell_sqlite3_result_zeroblob64
#define sqlite3_rollback_hook          duckdb_shell_sqlite3_rollback_hook
#define sqlite3_set_authorizer         duckdb_shell_sqlite3_set_authorizer
#define sqlite3_set_auxdata            duckdb_shell_sqlite3_set_auxdata
#define sqlite3_shutdown               duckdb_shell_sqlite3_shutdown
#define sqlite3_sleep                  duckdb_shell_sqlite3_sleep
#define sqlite3_snprintf               duckdb_shell_sqlite3_snprintf
#define sqlite3_sourceid               duckdb_shell_sqlite3_sourceid
#define sqlite3_sql                    duckdb_shell_sqlite3_sql
#define sqlite3_status64               duckdb_shell_sqlite3_status64
#define sqlite3_step                   duckdb_shell_sqlite3_step
#define sqlite3_stmt_busy              duckdb_shell_sqlite3_stmt_busy
#define sqlite3_stmt_isexplain         duckdb_shell_sqlite3_stmt_isexplain
#define sqlite3_stmt_readonly          duckdb_shell_sqlite3_stmt_readonly
#define sqlite3_stmt_status            duckdb_shell_sqlite3_stmt_status
#define sqlite3_strglob                duckdb_shell_sqlite3_strglob
#define sqlite3_stricmp                duckdb_shell_sqlite3_stricmp
#define sqlite3_strlike                duckdb_shell_sqlite3_strlike
#define sqlite3_strnicmp               duckdb_shell_sqlite3_strnicmp
#define sqlite3_table_column_metadata  duckdb_shell_sqlite3_table_column_metadata
#define sqlite3_test_control           duckdb_shell_sqlite3_test_control
#define sqlite3_threadsafe             duckdb_shell_sqlite3_threadsafe
#define sqlite3_total_changes          duckdb_shell_sqlite3_total_changes
#define sqlite3_total_changes64        duckdb_shell_sqlite3_total_changes64
#define sqlite3_trace                  duckdb_shell_sqlite3_trace
#define sqlite3_trace_v2               duckdb_shell_sqlite3_trace_v2
#define sqlite3_unlock_notify          duckdb_shell_sqlite3_unlock_notify
#define sqlite3_update_hook            duckdb_shell_sqlite3_update_hook
#define sqlite3_user_data              duckdb_shell_sqlite3_user_data
#define sqlite3_value_blob             duckdb_shell_sqlite3_value_blob
#define sqlite3_value_bytes            duckdb_shell_sqlite3_value_bytes
#define sqlite3_value_bytes16          duckdb_shell_sqlite3_value_bytes16
#define sqlite3_value_double           duckdb_shell_sqlite3_value_double
#define sqlite3_value_dup              duckdb_shell_sqlite3_value_dup
#define sqlite3_value_free             duckdb_shell_sqlite3_value_free
#define sqlite3_value_int              duckdb_shell_sqlite3_value_int
#define sqlite3_value_int64            duckdb_shell_sqlite3_value_int64
#define sqlite3_value_nochange         duckdb_shell_sqlite3_value_nochange
#define sqlite3_value_numeric_type     duckdb_shell_sqlite3_value_numeric_type
#define sqlite3_value_pointer          duckdb_shell_sqlite3_value_pointer
#define sqlite3_value_text             duckdb_shell_sqlite3_value_text
#define sqlite3_value_text16           duckdb_shell_sqlite3_value_text16
#define sqlite3_value_text16be         duckdb_shell_sqlite3_value_text16be
#define sqlite3_value_text16le         duckdb_shell_sqlite3_value_text16le
#define sqlite3_value_type             duckdb_shell_sqlite3_value_type
#define sqlite3_vfs_find               duckdb_shell_sqlite3_vfs_find
#define sqlite3_vfs_register           duckdb_shell_sqlite3_vfs_register
#define sqlite3_vmprintf               duckdb_shell_sqlite3_vmprintf
#define sqlite3_vsnprintf              duckdb_shell_sqlite3_vsnprintf
#define sqlite3_vtab_collation         duckdb_shell_sqlite3_vtab_collation
#define sqlite3_vtab_config            duckdb_shell_sqlite3_vtab_config
